OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Contraseña incorreuta",
    "The new password can not be the same as the previous one" : "La nueva contraseña nun puede ser la mesma que l'anterior",
    "No user supplied" : "Nun s'especificó un usuariu",
    "Authentication error" : "Fallu d'autenticación",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación d'alministrador incorreuta. Comprueba la contraseña ya inténtalo dempués.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "El backend nun sofita cambeos de contraseña, pero la contraseña de cifráu del usuariu anovóse afechiscamente.",
    "Unable to change password" : "Nun pudo camudase la contraseña",
    "Couldn't send reset email. Please contact your administrator." : "Nun pudo unviase'l corréu de reaniciu. Por favor, contauta col alministrador.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando y actualizando aplicaciones al traviés de la tienda d'aplicaciones o Nube Compartida Federada",
    "Federated Cloud Sharing" : "Nube Compartida Federada",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL ta utilizando una versión %s obsoleta (%s). Por favor, actualice'l so sistema operativu o característiques tales como %s nun va funcionar de forma fiable.",
    "A problem occurred, please check your log files (Error: %s)" : "Hebo un problema, por favor, compruebe los ficheros de rexistru (Fallu: %s)",
    "Migration Completed" : "Migración Completada",
    "Group already exists." : "El grupu yá esiste",
    "Unable to add group." : "Nun pudo amestase'l grupu",
    "Unable to delete group." : "Nun pudo desaniciase'l grupu",
    "log-level out of allowed range" : "Nivel de rexistru fuera del rangu permitíu",
    "Saved" : "Guardáu",
    "test email settings" : "probar configuración de corréu",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hebo un problema mientres s'unviaba'l corréu. Revisa la configuración.  (Fallu: %s)",
    "Email sent" : "Corréu-e unviáu",
    "You need to set your user email before being able to send test emails." : "Tienes de configurar la direición de corréu-e enantes de poder unviar mensaxes de prueba.",
    "Invalid mail address" : "Direición d'email inválida",
    "A user with that name already exists." : "Un usuariu con esi nome yá esiste.",
    "Unable to create user." : "Imposible crear l'usuariu.",
    "Your %s account was created" : "Creóse la so cuenta %s",
    "Unable to delete user." : "Nun pudo desaniciase l'usuariu",
    "Forbidden" : "Denegáu",
    "Invalid user" : "Usuariu inválidu",
    "Unable to change mail address" : "Nun pue camudase la direición d'email",
    "Your full name has been changed." : "Camudóse'l nome completu.",
    "Unable to change full name" : "Nun pue camudase'l nome completu",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Asturianu",
    "Language changed" : "Camudóse la llingua",
    "Invalid request" : "Solicitú inválida",
    "Admins can't remove themself from the admin group" : "Los alministradores nun puen desaniciase a ellos mesmos del grupu d'alministrador",
    "Unknown user" : "Usuariu desconocíu",
    "Couldn't remove app." : "Nun pudo desaniciase l'aplicación.",
    "Official" : "Oficial",
    "Approved" : "Aprobáu",
    "All" : "Toos",
    "Enabled" : "Habilitar",
    "Not enabled" : "Desactiváu",
    "No apps found for your version" : "Nun s'alcontró nenguna aplicación pa la to versión",
    "The app will be downloaded from the app store" : "L'aplicación va descargase dende la tienda d'aplicaciones",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Les aplicaciones oficiales desendolquenles la comunidá y dientro d'ownCloud. Ufierten una funcionalidá perimportante pa ownCloud y tán llistos pal so usu en producción.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Les aplicaciones aprobaes desendolquenles desarrolladores d'enfotu y pasaron un control de seguridá superficial. Caltiénense viviegamente nun repositorio de códigu abiertu y los sos mantenedores consideren que son estables pal usu normal.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Esta aplicación nun ta marcada por cuestiones de seguridá y ye nueva o conocíida por ser inestable. Instalala baxo'l to propiu riesgu.",
    "Please wait...." : "Espera, por favor....",
    "Error while disabling app" : "Fallu mientres se desactivaba l'aplicación",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Error while enabling app" : "Fallu mientres s'activaba l'aplicación",
    "Error: this app cannot be enabled because it makes the server unstable" : "Fallu: esta aplicación nun puede habilitase porque fai el sirvidor inestable",
    "Error: could not disable broken app" : "Fallu: nun pudo desaniciáse l'aplicación frañida",
    "Error while disabling broken app" : "Fallu mientres se deshabilitaba l'aplicación frañida",
    "Updating...." : "Anovando....",
    "Error while updating app" : "Fallu mientres s'anovaba l'aplicación",
    "Updated" : "Anováu",
    "Uninstalling ...." : "Desinstalando ...",
    "Error while uninstalling app" : "Fallu mientres se desinstalaba l'aplicación",
    "Uninstall" : "Desinstalar",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Habilitóse l'aplicación pero precisa anovamientu. Van redirixite a la páxina d'actualización en 5 segundos.",
    "App update" : "Anovar aplicación",
    "Experimental" : "Esperimental",
    "No apps found for {query}" : "Nun s'alcontró nenguna aplicación pa {query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "¿De xuru que quies amestar \"{domain}\" como dominiu de confianza?",
    "Add trusted domain" : "Amestar dominiu de confianza",
    "Migration in progress. Please wait until the migration is finished" : "La migración ta en cursu. Por favor, espere hasta que finr la migración",
    "Migration started …" : "La migración entamó ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Hebo un fallu. Por favor xube un certificáu d'ASCII-encoded PEM",
    "Valid until {date}" : "Válidu fasta {date}",
    "Delete" : "Desaniciar",
    "Disconnect" : "Desconeutar",
    "Error while loading browser sessions and device tokens" : "Fallu mientres cargaba la sesión del restolador y los token del preséu",
    "Error while creating device token" : "Fallu creando'l token del preséu",
    "Error while deleting the token" : "Fallu desaniciando'l token del preséu",
    "Sending..." : "Unviando...",
    "An error occurred: {message}" : "Hebo un fallu: {message}",
    "Select a profile picture" : "Esbillar una imaxe de perfil",
    "Very weak password" : "Contraseña mui feble",
    "Weak password" : "Contraseña feble",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña bona",
    "Strong password" : "Contraseña mui bona",
    "Groups" : "Grupos",
    "Unable to delete {objName}" : "Nun pue desaniciase {objName}",
    "Error creating group: {message}" : "Fallu creando grupu: {message}",
    "A valid group name must be provided" : "Hai d'escribir un nome de grupu válidu",
    "deleted {groupName}" : "desaniciáu {groupName}",
    "undo" : "desfacer",
    "never" : "enxamás",
    "deleted {userName}" : "desaniciáu {userName}",
    "add group" : "amestar Grupu",
    "Invalid quota value \"{val}\"" : "Valor \"{val}\" de cuota inválidu ",
    "enabled" : "activáu",
    "disabled" : "desactiváu",
    "no group" : "Ensín grupu",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Anovar la contraseña va dar llugar a la perda de datos, porque la recuperación de datos nun ta disponible pa esti usuariu",
    "Password successfully changed" : "Camudóse la contraseña",
    "A valid username must be provided" : "Tien d'apurrise un nome d'usuariu válidu",
    "Error creating user: {message}" : "Fallu creando usuariu: {message}",
    "A valid password must be provided" : "Tien d'apurrise una contraseña válida",
    "A valid email must be provided" : "Tien d'apurrise un corréu válidu",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hola, ¿qué hai?,<br><br>namái déxamos dicite qu'agora ties una cuenta %s<br><br>Nome d'usuariu: %s<br>Accede: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "¡Salú!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hola, ¿qué hai?,\n\nnamái déxamos dicite qu'agora ties una cuenta %s\n\nNome d'usuariu: %s\n\nAccede: %s\n\n",
    "User documentation" : "Documentación d'usuariu",
    "Administrator documentation" : "Documentación d'alministrador",
    "Online documentation" : "Documentación en llinia",
    "Forum" : "Foru",
    "Issue tracker" : "Siguidor de problemes",
    "Commercial support" : "Sofitu comercial",
    "Developer documentation" : "Documentación de desendolcador",
    "by %s" : "por %s",
    "%s-licensed" : "%s-con llicencia",
    "Documentation:" : "Documentación:",
    "Admin documentation" : "Documentación p'alministradores",
    "Visit website" : "Visitar sitiu web",
    "Report a bug" : "Reportar un fallu",
    "Show description …" : "Amosar descripción ...",
    "Hide description …" : "Anubrir descripción ...",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Esta aplicación nun tien nenguna versión mínima ownCloud asignada. Esti va ser un fallu en ownCloud 11 y posteriores.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Esta aplicación nun tien nenguna versión másica ownCloud asignada. Esti va ser un fallu en ownCloud 11 y posteriores.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación non puede instalase por cuenta que les siguientes dependencies nun se cumplen:",
    "Enable only for specific groups" : "Habilitar namái pa grupos específicos",
    "Uninstall App" : "Desinstalar aplicación",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Cabera execución de cron: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Cabera execución de cron: %s. Daqué paez tar mal.",
    "Cron was not executed yet!" : "¡Cron entá nun s'executó!",
    "Open documentation" : "Abrir documentación",
    "Execute one task with each page loaded" : "Executar una xera con cada páxina cargada",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php rexístrase nun serviciu webcron pa llamar a cron.php cada 15 minutos al traviés de HTTP.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Usar el serviciu cron del sistema pa llamar al ficheru cron.php cada 15 mins.",
    "SSL Root Certificates" : "Certificaos raíz SSL",
    "Common Name" : "Nome Común",
    "Valid until" : "Válidu fasta",
    "Issued By" : "Emitíu Por",
    "Valid until %s" : "Válidu fasta %s",
    "Import root certificate" : "Importar certificáu raíz",
    "Server-side encryption" : "Encriptación del llau del sirvidor",
    "Enable server-side encryption" : "Habilitar encriptación del lláu del sirvidor",
    "Please read carefully before activating server-side encryption: " : "Por favor, llea con cuidáu enantes d'activar el cifráu del llau del sirvidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vegada s'habilita la codificación, tolos ficheros xubíos al sirvidor dende esi puntu d'equí p'alantre van cifrase en reposu nel sirvidor. Namás va ser posible deshabilitar el cifráu nuna fecha posterior si'l módulu de cifráu activu soporta esa función, y toles condiciones previes (por exemplu, l'establecimientu d'una recuperación de la clave) se cumplan.",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "El cifráu por sí solo nun garantiza la seguridá del sistema. Por favor, consulte la documentación d'ownCloud pa llograr más información alrodiu de cómo funciona l'aplicación de cifráu, y los casos d'usu compatibles.",
    "Be aware that encryption always increases the file size." : "Ten en cuenta que'l cifráu siempres aumenta'l tamañu del ficheru.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempres ye bona pa crear copies de seguridá de tos datos, en casu d'encriptación asegúrate defacer una copia de seguridá de les claves de cifráu xuntu colos tos datos.",
    "This is the final warning: Do you really want to enable encryption?" : "Esti ye'l caberu avisu: ¿Daveres quies habilitar la encriptación?",
    "Enable encryption" : "Habilitar encriptación",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Ensin módulu de cifráu cargáu, por favor, activa un módulu de cifráu nel menú d'aplicaciones.",
    "Select default encryption module:" : "Seleiciona un módulu d'encriptación por defeutu: ",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Ye necesariu migrar les tos claves de cifráu de la vieya encriptación  (ownCloud <= 8.0) pa la nueva. Por favor, activa'l \"Módulu de cifráu por defectu\" y executa  'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Ye necesariu migrar les tos claves de cifráu de la vieya encriptación (ownCloud <= 8.0) pa la nueva.",
    "Start migration" : "Entamar migración",
    "Sharing" : "Compartiendo",
    "Allow apps to use the Share API" : "Permitir a les aplicaciones usar la API de Compartición",
    "Allow users to share via link" : "Permitir a los usuarios compartir vía enllaz",
    "Allow public uploads" : "Permitir xubes públiques",
    "Enforce password protection" : "Ameyora la proteición por contraseña.",
    "Set default expiration date" : "Afitar la data d'espiración predeterminada",
    "Allow users to send mail notification for shared files" : "Permitir a los usuarios unviar mensaxes de notificación pa ficheros compartíos",
    "Expire after " : "Caduca dempués de",
    "days" : "díes",
    "Enforce expiration date" : "Facer cumplir la data de caducidá",
    "Allow resharing" : "Permitir re-compartición",
    "Allow sharing with groups" : "Permitir compartir colos grupos",
    "Restrict users to only share with users in their groups" : "Restrinxir a los usuarios a compartir namái con otros usuarios nos sos grupos",
    "Allow users to send mail notification for shared files to other users" : "Permitir a los usuarios unviar mensaxes de notificación pa ficheros compartíos a otros usuarios",
    "Exclude groups from sharing" : "Esclúi grupos de compartir",
    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos van poder siguir recibiendo conteníos compartíos, pero nun van poder anicialos",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Permitir autocompletar nome d'usuariu nel diálogu d'acción. Si esto ta desactiváu, el nome d'usuariu completu tien d'introducise.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Too (Información, Avisos, Fallos, debug y problemes fatales)",
    "Info, warnings, errors and fatal issues" : "Información, Avisos, Fallos y problemes fatales",
    "Warnings, errors and fatal issues" : "Avisos, fallos y problemes fatales",
    "Errors and fatal issues" : "Fallos y problemes fatales",
    "Fatal issues only" : "Namái problemes fatales",
    "Log" : "Rexistru",
    "What to log" : "Elementos que se van rexistrar",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "El ficheru de rexistru ye más grande que 100 Mb. ¡La descarga puede tardar dalgún tiempu!",
    "None" : "Dengún",
    "Login" : "Entamar sesión",
    "Plain" : "Planu",
    "NT LAN Manager" : "Xestor de NT LAN",
    "Email server" : "Sirvidor d'email",
    "This is used for sending out notifications." : "Esto úsase pa unviar notificaciones.",
    "Send mode" : "Mou d'unviu",
    "Encryption" : "Cifráu",
    "From address" : "Dende la direición",
    "mail" : "corréu",
    "Authentication method" : "Métodu d'autenticación",
    "Authentication required" : "Necesítase autenticación",
    "Server address" : "Direición del sirvidor",
    "Port" : "Puertu",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nome d'usuariu SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Store credentials" : "Almacenar credenciales",
    "Test email settings" : "Probar configuración de corréu electrónicu",
    "Send email" : "Unviar mensaxe",
    "Security & setup warnings" : "Avisos de seguridá & configuración",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nun paez tar configuráu correchamente pa consultar les variables d'entornu del sistema. La prueba con getenv(\"PATH\") namás devuelve una respuesta balera.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor comprueba la  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentación d'instalación ↗</a> pa les notes de configuración de php y la configuración php del so sirvidor, especialmente cuando s'usa php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Habilitóse la configuración de namái llectura. Esto torga l'establecimientu de delles configuraciones al traviés de la interfaz web. Amás, el ficheru tien de tener permisu d'escritura manual pa cada actualización.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ta aparentemente configuráu pa desaniciar bloques de documentos en llinia. Esto va facer que delles aplicaciones principales nun tean accesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dablemente esto seya culpa d'un caché o acelerador, como por exemplu Zend OPcache o eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "La to base de datos nun s'executa col nivel d'aislamientu de transacción \"READ COMMITED\". Esto puede causar problemes cuando múltiples acciones s'executen en paralelu.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Ta instalada una versión %1$s per debaxo de la versión %2$s, por razones d'estabilidá y rendimientu encamiéntase l'actualización a una versión más recién %1$s.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Nun s'atopó'l módulu PHP 'fileinfo'. Encamentámoste qu'habilites esti módulu pa obtener meyores resultaos cola deteición de tribes MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "El bloquéu de ficheros transaccional ta desactiváu, esto podría conducir a problemes coles 'race conditions'. Habilita 'filelocking.enabled' en config.php pa evitar estos problemes. Llee la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentación ↗</a>  pa más información.",
    "System locale can not be set to a one which supports UTF-8." : "Nun se pue escoyer una configuración rexonal que sofite UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Esto significa que pue haber problemes con ciertos caráuteres nos nomes de los ficheros.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Ye enforma recomendable instalar los paquetes necesarios pa poder soportar una de les siguientes configuraciones llocales: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si la so instalación nun ta asitiada nel raigañu del dominiu y uses el cron del sistema, pues atopar problemas cola xeneración d'URL. Pa evitar estos problemes, afita la opción \"overwrite.cli.url\" nel tu ficheru config.php pa qu'use'l camín del raigañu la so instalación (Suxerencia: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite utilízase como base de datos. Pa instalaciones más grandes encamiéntase camudar a un motor de base de datos distintu.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especialmente cuando s'utiliza'l veceru d'escritoriu pa la sincronización de ficheros l'usu de SQLite ta desaconseyáu .",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Pa migrar a otra base de datos utilice la ferramienta de llínea de comandos : 'occ db:convert-type', o consulte la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentación↗</a>.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Nun foi posible executar la xera programada al traviés de CLI. Apaecieron los siguientes fallos técnicos:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor revisa les  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guíes d'instalación↗</a>, y compruebe si hai dalgún erru o alvertencia nel  <a href=\"#log-section\">rexistru</a>.",
    "All checks passed." : "Pasasti tolos controles",
    "Tips & tricks" : "Conseyos & trucos",
    "How to do backups" : "Cómo faer copies de seguridá",
    "Advanced monitoring" : "Monitorización avanzada",
    "Performance tuning" : "Optimización del rendimientu",
    "Improving the config.php" : "Meyora de config.php",
    "Theming" : "Personalizar la tema",
    "Hardening and security guidance" : "Guía de proteición y seguridá",
    "Get the apps to sync your files" : "Obtener les aplicaciones pa sincronizar ficheros",
    "Desktop client" : "Cliente d'escritoriu",
    "Android app" : "Aplicación d'Android",
    "iOS app" : "Aplicación d'iOS",
    "Show First Run Wizard again" : "Amosar nuevamente l'Encontu d'execución inicial",
    "Profile picture" : "Semeya de perfil",
    "Upload new" : "Xubir otra",
    "Select from Files" : "Esbillar dende Ficheros",
    "Remove image" : "Desaniciar imaxe",
    "png or jpg, max. 20 MB" : "png o jpg, masimu 20 MB",
    "Picture provided by original account" : "Imaxe proporcionada por cuenta orixinal",
    "Cancel" : "Encaboxar",
    "Choose as profile picture" : "Esbillar una imaxe de perfil",
    "Full name" : "Nome completu",
    "No display name set" : "Nun s'estableció nengún nome p'amosar",
    "Email" : "Corréu-e",
    "Your email address" : "Direición de corréu-e",
    "For password recovery and notifications" : "Pa la recuperación de contraseña y notificaciones",
    "No email address set" : "Nun s'estableció nenguna direición d'email",
    "You are member of the following groups:" : "Yes miembru de los siguientes grupos:",
    "Password" : "Contraseña",
    "Unable to change your password" : "Nun pudo camudase la contraseña",
    "Current password" : "Contraseña actual",
    "New password" : "Contraseña nueva",
    "Change password" : "Camudar contraseña",
    "Language" : "Llingua",
    "Help translate" : "Ayúdanos nes traducciones",
    "Unlimited" : "Non llendáu",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Desendolcáu pola {communityopen}comunidá d'ownCloud{linkclose}, el {githubopen}código fonte{linkclose} tien llicencia{licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Sesiones",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Estos son los veceros na web, n'escritoriu y nel móvil anguaño conectaos nel so OwnCloud.",
    "Browser" : "Restolador",
    "Most recent activity" : "Actividá más recién",
    "App passwords" : "Contraseñes d'aplicación",
    "You've linked these apps." : "Enllazasti estes aplicaciones.",
    "Name" : "Nome",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Una contraseña d'aplicación ye un códigu d'accesu que da permisu a una aplicación o dispositivo p'aportar a la so cuenta %s.",
    "App name" : "Nome d'aplicación",
    "Create new app password" : "Crear nueva contraseña d'aplicación",
    "Use the credentials below to configure your app or device." : "Usar les credenciales de baxo pa configurar la so aplicación o preséu.",
    "Username" : "Nome d'usuariu",
    "Done" : "Fechu",
    "Version" : "Versión",
    "Personal" : "Personal",
    "Admin" : "Almin",
    "Error" : "Fallu",
    "Show storage location" : "Amosar llocalización d'almacenamientu",
    "Show last log in" : "Amosar el caberu aniciu de sesión",
    "Show user backend" : "Amosar motor d'usuariu",
    "Send email to new user" : "Unviar corréu al nuevu usuariu",
    "Show email address" : "Amosar direición de corréu",
    "E-Mail" : "Corréu",
    "Create" : "Crear",
    "Admin Recovery Password" : "Recuperación de la contraseña d'alministración",
    "Enter the recovery password in order to recover the users files during password change" : "Introduz la contraseña de recuperación col envís de recuperar los ficheros de los usuarios mientres el cambéu de contraseña.",
    "Add Group" : "Amestar grupu",
    "Group" : "Grupu",
    "Everyone" : "Toos",
    "Admins" : "Almins",
    "Default Quota" : "Cuota predeterminada",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor indica la cuota d'almacenamientu (ex: \"512 MB\" o \"12 GB\")",
    "Other" : "Otru",
    "Full Name" : "Nome completu",
    "Group Admin for" : "Alministrador del Grupu pa",
    "Quota" : "Cuota",
    "Storage Location" : "Llocalización d'almacenamientu",
    "User Backend" : "Motor d'Usuariu",
    "Last Login" : "Caberu aniciu de sesión",
    "change full name" : "camudar el nome completu",
    "set new password" : "afitar nueva contraseña",
    "change email address" : "camudar direición d'email",
    "Default" : "Predetermináu",
    "Share" : "Compartir",
    "Domain" : "Dominiu",
    "Add" : "Amestar"
},
"nplurals=2; plural=(n != 1);");
